@@ -2,7 +2,11 @@
 from sclblpy._bundle import _gzip_save, _gzip_load, _gzip_delete
 
 # Script settings:
+from sclblpy.main import _toggle_debug_mode, stop_print
+
 RUN_TESTS = False  # Prevent unintended testing
+DEBUG = False  # Set to debug mode; if true it will raise exceptions
+PRINTING = False  # Toggle printing on and off.
 
 def test_gzip_save():
     """Test gzip save. """
@@ -12,7 +16,6 @@ def test_gzip_save():
 
     # Test w. print
     _gzip_save(obj)
-    _gzip_save(obj, _verbose=False)
 
 
 def test_gzip_load():
@@ -20,6 +23,7 @@ def test_gzip_load():
     obj = _gzip_load()
     assert obj["example"] == "model", "Should be true"
 
+
 def test_gzip_delete():
     _gzip_delete()
 
@@ -31,6 +35,12 @@ if __name__ == '__main__':
         print("Not running tests.")
         exit()
 
+    if not PRINTING:
+        stop_print()
+
+    if DEBUG:
+        _toggle_debug_mode()
+
     print("Running tests of _bundle.py")
     print("===============================")
 
